@@ -10,11 +10,12 @@ import zipfile
 import re
 from getpass import getpass
 
+from tqdm import tqdm
 from pyrogram.session import Session 
 from pyrogram import Client, filters, types, session
 
 BASE_FOLDER = Path(__file__).parent.absolute()
-logging.basicConfig(level=logging.WARNING, format='%(asctime)s %(name)-12s %(levelname)-8s %(message)s', datefmt='%y-%m-%d %H:%M:%S')
+logging.basicConfig(level=logging.CRITICAL, format='%(asctime)s %(name)-12s %(levelname)-8s %(message)s', datefmt='%y-%m-%d %H:%M:%S')
 Session.notice_displayed = True # Disable notice from pyrogram
 
 class Bot:
@@ -48,27 +49,29 @@ def zipdir(dir_name):
     return zip_file
 
 
-def send_data(data: str, user:str = "me", data_type:str = "text", caption: str = None, force_file:bool = False):
+def send_data(data: str, user:str = "me", data_type:str = "text", caption: str = None, as_file:bool = False, parse_mode = 'html'):
     """
     Connect to bot and send data to user
     """
     my_bot = Bot()
     with my_bot as app:
         if data_type == "text":
-            if len(data) > 4096 or force_file:
-                # print("Text is longer than 4096, sending as file")
+            if as_file:
                 temp_file = BASE_FOLDER / "data/text_message.txt"
                 with open(temp_file, "w") as f:
                     f.write(data)
                 app.send_document(user, temp_file)
                 temp_file.unlink()
             else:
-                app.send_message(user, data)
+                app.send_message(user, data, parse_mode = parse_mode)
         elif data_type == "file":
-            if caption is None:
-                app.send_document(user, data)
-            else:
-                app.send_document(user, data, caption=caption[:1024])
+            with tqdm(total=100) as pbar:  
+                def progress(current, total):
+                    pbar.update(round(current * 100 / total, 4) - pbar.n) 
+                if caption is not None:
+                    app.send_document(user, data, caption=caption[:1024], progress=progress)
+                else:
+                    app.send_document(user, data, progress=progress)
 
 
 def main():
@@ -81,6 +84,7 @@ def main():
     parser.add_argument('-f', '--file', action="store", type=str, help='send file, text will be sended as caption. If folder is sended, will zip and send')
     parser.add_argument('-c', '--code', action='store_true', help='send text with <code> text to make it monospace')
     parser.add_argument('-F', '--force-file', action='store_true', help='send text in file even if it is shorter than 4096 symbols')
+    parser.add_argument('--no-html', action='store_true', help='do not parse as html')
     parser.add_argument('--ansi-colors', action='store_true', help="don't remove ANSI escape codes from piped strings")
     parser.add_argument('--new-user', action='store_true', help='reloging to telegram')
     parser.add_argument('--new-app', action='store_true', help='enter new api_id/api_hash combination')
@@ -94,6 +98,11 @@ def main():
             ansi_escape = re.compile(r'\x1B(?:[@-Z\\-_]|\[[0-?]*[ -/]*[@-~])')
             pipe = ansi_escape.sub('', pipe)
     
+    if args.no_html:
+        parse_mode = None
+    else:
+        parse_mode = "html"
+
     # Text handling
     message_text = None
     if args.message:
@@ -106,7 +115,12 @@ def main():
         print("No message to send, sending test message to Saved Messages. For help, use -h, --help.")
         # message_text = hex(random.randrange(0x10000000000, 0x99999999999))
         message_text = f"Hello World!\n\n\n<i>With Love from teleout</i>"
-    if args.code:
+
+    as_file = False
+    if message_text is None or len(message_text) > 4000 or args.force_file:
+        as_file = True
+
+    if args.code and not as_file:
         message_text = "<code>{}</code>".format(message_text)
 
     # File handling
@@ -138,7 +152,7 @@ def main():
 
     user = "me" if args.user is None else args.user
     if args.file is None:
-        send_data(message_text, user=user, data_type="text", force_file=args.force_file)
+        send_data(message_text, user=user, data_type="text", as_file=as_file, parse_mode=parse_mode)
     else:
         send_data(file, caption=message_text, user=user, data_type="file")
     if delete_file:
